Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(295)

Unified Diff: third_party/WebKit/Source/platform/FrameViewBase.h

Issue 2722953003: Part 1 to rename platform/Widget to platform/FrameViewBase. (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/platform/BUILD.gn ('k') | third_party/WebKit/Source/platform/FrameViewBase.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/platform/FrameViewBase.h
diff --git a/third_party/WebKit/Source/platform/Widget.h b/third_party/WebKit/Source/platform/FrameViewBase.h
similarity index 82%
copy from third_party/WebKit/Source/platform/Widget.h
copy to third_party/WebKit/Source/platform/FrameViewBase.h
index 2c59cb0a6a31dd3addb94e191feb1321aef6d069..7f052e1bec55a45c355d93411a03b8d1dd035d1a 100644
--- a/third_party/WebKit/Source/platform/Widget.h
+++ b/third_party/WebKit/Source/platform/FrameViewBase.h
@@ -25,8 +25,8 @@
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-#ifndef Widget_h
-#define Widget_h
+#ifndef FrameViewBase_h
+#define FrameViewBase_h
#include "platform/PlatformExport.h"
#include "platform/geometry/FloatPoint.h"
@@ -41,16 +41,16 @@ class CullRect;
class Event;
class GraphicsContext;
// The Widget class serves as a base class for FrameView, Scrollbar, and
// PluginView.
//
// Widgets are connected in a hierarchy, with the restriction that plugins and
// scrollbars are always leaves of the tree. Only FrameView can have children
-// (and therefore the Widget class has no concept of children).
-class PLATFORM_EXPORT Widget : public GarbageCollectedFinalized<Widget> {
+// (and therefore the FrameViewBase class has no concept of children).
+class PLATFORM_EXPORT FrameViewBase : public GarbageCollectedFinalized<FrameViewBase> {
public:
- Widget();
- virtual ~Widget();
+ FrameViewBase();
+ virtual ~FrameViewBase();
int x() const { return frameRect().x(); }
int y() const { return frameRect().y(); }
@@ -94,9 +94,9 @@ class PLATFORM_EXPORT Widget : public GarbageCollectedFinalized<Widget> {
virtual bool isPluginContainer() const { return false; }
virtual bool isScrollbar() const { return false; }
- virtual void setParent(Widget*);
- Widget* parent() const { return m_parent; }
- Widget* root() const;
+ virtual void setParent(FrameViewBase *);
+ FrameViewBase* parent() const { return m_parent; }
+ FrameViewBase* root() const;
virtual void handleEvent(Event*) {}
@@ -116,18 +116,18 @@ class PLATFORM_EXPORT Widget : public GarbageCollectedFinalized<Widget> {
virtual IntPoint convertToContainingWidget(const IntPoint&) const;
virtual IntPoint convertFromContainingWidget(const IntPoint&) const;
- // Virtual methods to convert points to/from child widgets
- virtual IntPoint convertChildToSelf(const Widget*, const IntPoint&) const;
- virtual IntPoint convertSelfToChild(const Widget*, const IntPoint&) const;
+ // Virtual methods to convert points to/from child frameviewbases.
+ virtual IntPoint convertChildToSelf(const FrameViewBase *, const IntPoint&) const;
+ virtual IntPoint convertSelfToChild(const FrameViewBase *, const IntPoint&) const;
- // Notifies this widget that it will no longer be receiving events.
+ // Notifies this frameviewbase that it will no longer be receiving events.
virtual void eventListenersRemoved() {}
DECLARE_VIRTUAL_TRACE();
virtual void dispose() {}
private:
- Member<Widget> m_parent;
+ Member<FrameViewBase> m_parent;
IntRect m_frameRect;
bool m_selfVisible;
bool m_parentVisible;
@@ -135,4 +135,4 @@ class PLATFORM_EXPORT Widget : public GarbageCollectedFinalized<Widget> {
} // namespace blink
-#endif // Widget_h
+#endif // FrameViewBase_h
« no previous file with comments | « third_party/WebKit/Source/platform/BUILD.gn ('k') | third_party/WebKit/Source/platform/FrameViewBase.cpp » ('j') | no next file with comments »

Powered by Google App Engine
@@ -41,16 +41,16 @@ class CullRect;
class Event;
class GraphicsContext;
-// The Widget class serves as a base class for FrameView, Scrollbar, and
+// The FrameViewBase class serves as a base class for FrameView, Scrollbar, and
// PluginView.
//
@@ -41,16 +41,16 @@ class CullRect;
// PluginView.
//
-// Widgets are connected in a hierarchy, with the restriction that plugins and
+// FrameViewBases are connected in a hierarchy, with the restriction that plugins and
// scrollbars are always leaves of the tree. Only FrameView can have children
This is Rietveld 408576698